@@ -1,11 +1,13 @@
 """Module to read yaml or json conf"""
 import logging
+import os
 import re
 from typing import Dict, Union, Text, Tuple, Iterable
 
 import anyconfig
 
-from pyms.constants import CONFIGMAP_FILE_ENVIRONMENT, LOGGER_NAME, DEFAULT_CONFIGMAP_FILENAME
+from pyms.constants import CONFIGMAP_FILE_ENVIRONMENT, LOGGER_NAME, DEFAULT_CONFIGMAP_FILENAME, \
+    CONFIGMAP_FILE_ENVIRONMENT_LEGACY
 from pyms.exceptions import AttrDoesNotExistException, ConfigDoesNotFoundException
 from pyms.utils.files import LoadFile
 
@@ -14,7 +16,7 @@ logger = logging.getLogger(LOGGER_NAME)
 
 class ConfFile(dict):
     """Recursive get configuration from dictionary, a config file in JSON or YAML format from a path or
-    `CONFIGMAP_FILE` environment variable.
+    `PYMS_CONFIGMAP_FILE` environment variable.
     **Atributes:**
     * path: Path to find the `DEFAULT_CONFIGMAP_FILENAME` and `DEFAULT_KEY_FILENAME` if use encrypted vars
     * empty_init: Allow blank variables
@@ -26,7 +28,7 @@ class ConfFile(dict):
     def __init__(self, *args, **kwargs):
         """
         Get configuration from a dictionary(variable `config`), from path (variable `path`) or from
-        environment with the constant `CONFIGMAP_FILE`
+        environment with the constant `PYMS_CONFIGMAP_FILE`
         Set the configuration as upper case to inject the keys in flask config. Flask search for uppercase keys in
         `app.config.from_object`
         ```python
@@ -34,7 +36,10 @@ class ConfFile(dict):
             self[key] = getattr(obj, key)
         ```
         """
-        self._loader = LoadFile(kwargs.get("path"), CONFIGMAP_FILE_ENVIRONMENT, DEFAULT_CONFIGMAP_FILENAME)
+        # TODO Remove temporally backward compatibility on future versions
+        configmap_file_env = self.__get_updated_configmap_file_env()  # Temporally backward compatibility
+
+        self._loader = LoadFile(kwargs.get("path"), configmap_file_env, DEFAULT_CONFIGMAP_FILENAME)
         self._crypt_cls = kwargs.get("crypt")
         if self._crypt_cls:
             self._crypt = self._crypt_cls(path=kwargs.get("path"))
@@ -51,7 +56,7 @@ class ConfFile(dict):
 
         config = self.set_config(config)
 
-        super(ConfFile, self).__init__(config)
+        super().__init__(config)
 
     def to_flask(self) -> Dict:
         return ConfFile(config={k.upper(): v for k, v in self.items()}, crypt=self._crypt_cls)
@@ -110,10 +115,10 @@ class ConfFile(dict):
             for k in keys:
                 aux_dict = aux_dict[k]
             return aux_dict
-        except KeyError:
+        except KeyError as e:
             if self._empty_init:
                 return ConfFile(config={}, empty_init=self._empty_init, crypt=self._crypt_cls)
-            raise AttrDoesNotExistException("Variable {} not exist in the config file".format(name))
+            raise AttrDoesNotExistException("Variable {} not exist in the config file".format(name)) from e
 
     def reload(self):
         """
@@ -124,4 +129,11 @@ class ConfFile(dict):
         self.set_config(config_src)
 
     def __setattr__(self, name, value, *args, **kwargs):
-        super(ConfFile, self).__setattr__(name, value)
+        super().__setattr__(name, value)
+
+    @staticmethod
+    def __get_updated_configmap_file_env() -> str:
+        result = CONFIGMAP_FILE_ENVIRONMENT
+        if (os.getenv(CONFIGMAP_FILE_ENVIRONMENT_LEGACY) is not None) and (os.getenv(CONFIGMAP_FILE_ENVIRONMENT) is None):
+            result = CONFIGMAP_FILE_ENVIRONMENT_LEGACY
+        return result
