@@ -1,6 +1,6 @@
 import logging
 import os
-from typing import Text
+from typing import List, Optional
 
 from flask import Flask
 
@@ -10,7 +10,8 @@ from pyms.constants import LOGGER_NAME, CONFIG_BASE
 from pyms.crypt.driver import CryptResource
 from pyms.flask.app.utils import SingletonMeta, ReverseProxied
 from pyms.flask.healthcheck import healthcheck_blueprint
-from pyms.flask.services.driver import ServicesResource
+from pyms.flask.configreload import configreload_blueprint
+from pyms.flask.services.driver import ServicesResource, DriverService
 from pyms.logger import CustomJsonFormatter
 from pyms.utils import check_package_exists, import_from
 
@@ -38,7 +39,7 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         app.run()
     ```
     Environments variables of PyMS:
-    **CONFIGMAP_FILE**: The path to the configuration file. By default, PyMS search the configuration file in your
+    **PYMS_CONFIGMAP_FILE**: The path to the configuration file. By default, PyMS search the configuration file in your
     actual folder with the name "config.yml"
 
     ## Create configuration
@@ -72,11 +73,12 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
     Current services are swagger, request, tracer, metrics
     """
     config_resource = CONFIG_BASE
-    services = []
-    application = None
-    swagger = False
-    request = False
-    tracer = False
+    services: List[str] = []
+    application = Flask
+    swagger: Optional[DriverService] = None
+    request: Optional[DriverService] = None
+    tracer: Optional[DriverService] = None
+    metrics: Optional[DriverService] = None
     _singleton = True
 
     def __init__(self, *args, **kwargs):
@@ -137,7 +139,7 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         """Set attribute in flask `tracer`. See in `pyms.flask.services.tracer` how it works
         :return: None
         """
-        if self._exists_service("tracer"):
+        if self.tracer:
             FlaskTracing = import_from("flask_opentracing", "FlaskTracing")
             client = self.tracer.get_client()
             self.application.tracer = FlaskTracing(client, True, self.application)
@@ -169,7 +171,7 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
         run a "normal" Flask app.
         :return: None
         """
-        if self._exists_service("swagger"):
+        if self.swagger:
             application = self.swagger.init_app(config=self.config.to_flask(), path=self.path)
         else:
             check_package_exists("flask")
@@ -183,11 +185,11 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
 
         return application
 
-    def init_metrics(self):
+    def init_metrics(self) -> None:
         """Set attribute in flask `metrics`. See in `pyms.flask.services.metrics` how it works
         :return: None
         """
-        if getattr(self, "metrics", False) and self.metrics:
+        if self.metrics:
             self.application.register_blueprint(self.metrics.metrics_blueprint)
             self.metrics.add_logger_handler(
                 self.application.logger,
@@ -217,6 +219,7 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
 
         # Initialize Blueprints
         self.application.register_blueprint(healthcheck_blueprint)
+        self.application.register_blueprint(configreload_blueprint)
 
         self.init_libs()
         self.add_error_handlers()
@@ -231,14 +234,6 @@ class Microservice(ConfigResource, metaclass=SingletonMeta):
 
         return self.application
 
-    def _exists_service(self, service_name: Text) -> bool:
-        """Check if service exists in the config.yml file
-        :param service_name:
-        :return: bool
-        """
-        service = getattr(self, service_name, False)
-        return service and service is not None
-
     def add_error_handlers(self):
         """Subclasses will override this method in order to add specific error handlers. This should be done with
         calls to add_error_handler method.
